netapp_ontap.models.ipv6_interface API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.ipv6_interface`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class Ipv6InterfaceSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the Ipv6Interface object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `address: str GET PATCH`

    IPv6 address

    Example: fd20:8b1e:b255:5011:10:141:4:97

  `enabled: bool GET PATCH`

    Indicates whether the IPv6 interfaces is enabled. It expects values for address, netmask and gateway when set to "true".

  `gateway: str GET PATCH`

    The IPv6 address of the default router.

    Example: fd20:8b1e:b255:5011:10::1

  `is_ipv6_ra_enabled: bool GET PATCH`

    Indicates whether IPv6 RA is enabled.

  `link_local_ip: str GET PATCH`

    Link local IP address.

    Example: FE80::/10

  `netmask: Size GET PATCH`

    The IPv6 netmask/prefix length. The default value is 64 with a valid range of 1 to 127.

    Example: 64

  `router_ip: str GET PATCH`

    Router assigned IP address.

    Example: 2001:0db8:85a3:0000:0000:8a2e:0370:7334

  `setup_state: str GET`

    Indicates the setup state of the interface.

    Valid choices:

    - not_setup
    - succeeded
    - in_progress
    - failed